From 8be3ae3eddce73846692943912e57520e7df032a Mon Sep 17 00:00:00 2001
From: Heikki Linnakangas <heikki.linnakangas@iki.fi>
Date: Tue, 26 Mar 2024 12:47:41 +0200
Subject: [PATCH v9.heikki 8/9] Use wipe_mem() for callback data that should be
 considered invalid

wipe_mem() includes Valgrind hints, which is nice.
---
 src/backend/storage/aio/streaming_read.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/backend/storage/aio/streaming_read.c b/src/backend/storage/aio/streaming_read.c
index 76ce9cef53e..0ed81017b78 100644
--- a/src/backend/storage/aio/streaming_read.c
+++ b/src/backend/storage/aio/streaming_read.c
@@ -90,6 +90,7 @@
 #include "storage/fd.h"
 #include "storage/smgr.h"
 #include "storage/streaming_read.h"
+#include "utils/memdebug.h"
 #include "utils/rel.h"
 #include "utils/spccache.h"
 
@@ -618,13 +619,12 @@ streaming_read_buffer_next(StreamingRead *stream, void **per_buffer_data)
 	}
 
 	/* Advance the oldest buffer, but clobber it first for debugging. */
-#ifdef USE_ASSERT_CHECKING
+#ifdef CLOBBER_FREED_MEMORY
 	stream->buffers[oldest_buffer_index] = InvalidBuffer;
 	stream->buffer_io_indexes[oldest_buffer_index] = -1;
 	if (stream->per_buffer_data)
-		memset(get_per_buffer_data(stream, oldest_buffer_index),
-			   0xff,
-			   stream->per_buffer_data_size);
+		wipe_mem(get_per_buffer_data(stream, oldest_buffer_index),
+				 stream->per_buffer_data_size);
 #endif
 	if (++stream->oldest_buffer_index == stream->max_pinned_buffers)
 		stream->oldest_buffer_index = 0;
-- 
2.39.2

